local ADDON = ...

-- Retrieve addon databases
local Auras = CogWheel("LibDB"):GetDatabase(ADDON..": Auras")
local Colors = CogWheel("LibDB"):GetDatabase(ADDON..": Colors")
local Fonts = CogWheel("LibDB"):GetDatabase(ADDON..": Fonts")
local L = CogWheel("LibLocale"):GetLocale(ADDON)

-- Lua API
local math_pi = math.pi

-- Blizzard textures for generic styling
local BLANK_TEXTURE = [[Interface\ChatFrame\ChatFrameBackground]]
local BLING_TEXTURE = [[Interface\Cooldown\star4]]
local EDGE_LOC_TEXTURE = [[Interface\Cooldown\edge-LoC]]
local EDGE_NORMAL_TEXTURE = [[Interface\Cooldown\edge]]

-- Proxy function to get media from our local media folder
local getPath = function(fileName)
	return ([[Interface\AddOns\%s\media\%s.tga]]):format(ADDON, fileName)
end 

-- Convert degrees to radians
local degreesToRadians = function(degrees)
	return degrees * (2*math_pi)/180
end 

-- Core
local Core = {
	ShowWelcomeMessage = true, 
	FadeInUI = true, 
	DisableUIWidgets = {
		ActionBars = true,
		Alerts = true,
		Auras = true,
		--CaptureBars = true,
		CastBars = true,
		Chat = true,
		LevelUpDisplay = true,
		Minimap = true,
		--ObjectiveTracker = true,
		OrderHall = true,
		Tutorials = true,
		UnitFrames = true,
		--Warnings = true,
		WorldMap = true,
		WorldState = true,
		ZoneText = true
	},
	DisableUIMenuPages = {
		{ ID = 5, Name = "InterfaceOptionsActionBarsPanel" }
	},
	EasySwitch = {
		["AzeriteUI"] = { azeriteui = true, azerite = true, azerui = true, azui = true, az = true }
	}
}

-- ActionBars
local ActionBarMain = {

	-- Bar Layout
	-------------------------------------------------------
	UseHardCodedLayout = true, -- kill off the layout updates 
	UseActionBarMenu = false, -- kill of the actionbar menu


	-- XP and AP Bars
	-------------------------------------------------------
	UseStatusBars = true, 


	-- Button Layout
	-------------------------------------------------------
	-- Generic
	ButtonSize = { 54, 54 },
	MaskTexture = BLANK_TEXTURE, 

	-- Icon
	IconSize = { 44, 44 },
	IconPlace = { "CENTER", 0, 0 },
	IconTexCoord = { 5/64, 59/64, 5/64, 59/64 }, 

	UseIconShade = true, 
		IconShadeTexture = getPath("shade-square"),
		IconShadeDrawLayer = { "BACKGROUND", 4 },
	
	UseSlot = true, 
		SlotSize = { 44, 44 }, 
		SlotPlace = { "CENTER", 0, 0 },
		SlotTexture = getPath("button-slot"), 
		SlotColor = { Colors.ui.stone[1], Colors.ui.stone[2], Colors.ui.stone[3] },

	-- Button Pushed Icon Overlay
	PushedSize = { 44, 44 },
	PushedPlace = { "CENTER", 0, 0 },
	PushedColor = { 1, 1, 1, .15 },
	PushedDrawLayer = { "ARTWORK", 1 },
	PushedBlendMode = "ADD",

	-- Auto-Attack Flash
	FlashSize = { 44, 44 },
	FlashPlace = { "CENTER", 0, 0 },
	FlashColor = { 1, 0, 0, .25 },
	FlashTexture = BLANK_TEXTURE,
	FlashDrawLayer = { "ARTWORK", 2 },

	-- Cooldown Count Number
	CooldownCountPlace = { "CENTER", 1, 0 },
	CooldownCountJustifyH = "CENTER",
	CooldownCountJustifyV = "MIDDLE",
	CooldownCountFont = Fonts(14, true),
	CooldownCountShadowOffset = { 0, 0 },
	CooldownCountShadowColor = { 0, 0, 0, 1 },
	CooldownCountColor = { Colors.highlight[1], Colors.highlight[2], Colors.highlight[3], .85 },

	-- Cooldown 
	CooldownSize = { 44, 44 },
	CooldownPlace = { "CENTER", 0, 0 },
	CooldownSwipeTexture = BLANK_TEXTURE,
	CooldownBlingTexture = getPath("empty"),
	CooldownSwipeColor = { 0, 0, 0, .75 },
	CooldownBlingColor = { 0, 0, 0 , 0 },
	ShowCooldownSwipe = true,
	ShowCooldownBling = true,

	-- Charge Cooldown 
	ChargeCooldownSize = { 44, 44 },
	ChargeCooldownPlace = { "CENTER", 0, 0 },
	ChargeCooldownSwipeColor = { 0, 0, 0 , 0 },
	ChargeCooldownBlingColor = { 0, 0, 0 , 0 },
	ChargeCooldownSwipeTexture = getPath("empty"),
	ChargeCooldownBlingTexture = getPath("empty"),
	ShowChargeCooldownSwipe = false,
	ShowChargeCooldownBling = false,

	-- Charge Count / Stack Size Text
	CountPlace = { "BOTTOMRIGHT", -3, 3 },
	CountJustifyH = "CENTER",
	CountJustifyV = "BOTTOM",
	CountFont = Fonts(16, true),
	CountShadowOffset = { 0, 0 },
	CountShadowColor = { 0, 0, 0, 1 },
	CountColor = { Colors.normal[1], Colors.normal[2], Colors.normal[3], .85 },

	-- Keybind Text
	KeybindPlace = { "TOPLEFT", 5, -5 },
	KeybindJustifyH = "CENTER",
	KeybindJustifyV = "BOTTOM",
	KeybindFont = Fonts(13, true),
	KeybindShadowOffset = { 0, 0 },
	KeybindShadowColor = { 0, 0, 0, 1 },
	KeybindColor = { Colors.quest.gray[1], Colors.quest.gray[2], Colors.quest.gray[3], .75 },

	-- Overlay Glow
	OverlayGlowPlace = { "CENTER", 0, 0 },
	OverlayGlowSize = { 64 * 1.05, 64 * 1.05 },
	OverlayGlowSparkTexture = [[Interface\SpellActivationOverlay\IconAlert]],
	OverlayGlowInnerGlowTexture = [[Interface\SpellActivationOverlay\IconAlert]],
	OverlayGlowInnerGlowOverTexture = [[Interface\SpellActivationOverlay\IconAlert]],
	OverlayGlowOuterGlowTexture = [[Interface\SpellActivationOverlay\IconAlert]],
	OverlayGlowOuterGlowOverTexture = [[Interface\SpellActivationOverlay\IconAlert]],
	OverlayGlowAntsTexture = [[Interface\SpellActivationOverlay\IconAlertAnts]],

	-- Backdrop 
	BackdropPlace = { "CENTER", 0, 0 },
	BackdropSize = { 64/(122/256), 64/(122/256) },
	BackdropTexture = getPath("actionbutton-backdrop"),
	BackdropDrawLayer = { "BACKGROUND", 1 },

	-- Border 
	UseBorderBackdrop = true,
		BorderFramePlace = { "CENTER", 0, 0 },
		BorderFrameSize = { 54 + 30, 54 + 30 },
		BorderFrameBackdrop = { edgeFile = getPath("border-tooltip"), edgeSize = 32 },
		BorderFrameBackdropColor = { 0, 0, 0, 0 },
		BorderFrameBackdropBorderColor = { Colors.ui.stone[1], Colors.ui.stone[2], Colors.ui.stone[3] },

	-- Gloss
	GlowPlace = { "CENTER", 0, 0 },
	GlowSize = { 44/(122/256),44/(122/256) },
	GlowTexture = getPath("actionbutton-glow-white"),
	GlowDrawLayer = { "ARTWORK", 1 },
	GlowBlendMode = "ADD",
	GlowColor = { 1, 1, 1, .5 }

}

local BlizzardChatFrames = {

	DefaultChatFramePlace = { "BOTTOMLEFT", 85 - 15, 54 },
	DefaultChatFrameSize = { 519 - 100, 196 },
	DefaultClampRectInsets = { -54, -54, -54, -54 },


}

local BlizzardMicroMenu = {

	ButtonFont = Fonts(14, true),
	ButtonFontColor = { Colors.normal[1], Colors.normal[2] ,Colors.normal[3] }, 
	ButtonFontShadowOffset = { 0, 0 },
	ButtonFontShadowColor = { 0, 0, 0, 0 },

	UseBorderBackdrop = true,
		BorderFramePlace = { "CENTER", 0, 0 },
		BorderFrameSize = { 300 + 46, 74 + 46 },
		BorderFrameBackdrop = { edgeFile = getPath("border-tooltip"), edgeSize = 32 },
		BorderFrameBackdropColor = { 0, 0, 0, 0 },
		BorderFrameBackdropBorderColor = { Colors.ui.stone[1], Colors.ui.stone[2], Colors.ui.stone[3] },

	ConfigButtonBackdrop = {},

	ConfigWindowBackdrop = { 
		bgFile = BLANK_TEXTURE,
		edgeFile = getPath("border-tooltip"), edgeSize = 32,
		insets = { 
			top = 23, 
			bottom = 23, 
			left = 23, 
			right = 23
		}
	}
}

local BlizzardObjectivesTracker = {
	Place = { "TOPRIGHT", -(110/2 + 40), -400 },
	Width = 110,
	SpaceTop = 400, 
	SpaceBottom = 260, 
	MaxHeight = 480,
}

-- Minimap
local Minimap = {

	Size = { 220 *256/288, 220 *256/288 }, 
	Place = { "TOPRIGHT", "UICenter", "TOPRIGHT", -53, -59 }, 

	MaskTexture = getPath("minimap-mask-circle-transparent"),
	BackdropTexture = getPath("minimap-mask-circle"),
	OverlayTexture = getPath("minimap-mask-circle"),

	BorderPlace = { "CENTER", 0, 0 }, 
		BorderSize = { 256,256 }, 
		BorderTexture = getPath("minimap-border"),
		BorderColor = { Colors.ui.stone[1], Colors.ui.stone[2], Colors.ui.stone[3] }, 

	ClockFrameInOverlay = true, 
	ClockPlace = { "BOTTOM", 0, 16 },
	ClockFont = Fonts(15, true),
	ClockColor = { Colors.offwhite[1], Colors.offwhite[2], Colors.offwhite[3] }, 

	ZonePlaceFunc = function(Handler) return "TOP", Handler, "BOTTOM", 0, -36 end,
	ZoneFont = Fonts(14, true),
	ZoneAlpha = .75,

	CoordinatePlaceFunc = function(Handler) return "TOP", Handler.Zone, "BOTTOM", 0, -6 end,
	CoordinateColor = { Colors.quest.gray[1], Colors.quest.gray[2], Colors.quest.gray[3], .75 }, 

	LatencyPlace = { "BOTTOMRIGHT", "UICenter", "BOTTOMRIGHT", -110, 40 },
	LatencyFont = Fonts(12, true), 
	LatencyColor = { Colors.offwhite[1], Colors.offwhite[2], Colors.offwhite[3], .5 },
	
	FrameRatePlaceFunc = function(Handler) return "RIGHT", Handler.Latency, "LEFT", -6, 0 end,
	FrameRateFont = Fonts(12, true), 
	FrameRateColor = { Colors.offwhite[1], Colors.offwhite[2], Colors.offwhite[3], .5 },

	PerformanceFramePlaceAdvancedFunc = function(performanceFrame, Handler)
		performanceFrame:SetPoint("TOPLEFT", Handler.FrameRate, "TOPLEFT", 0, 0)
		performanceFrame:SetPoint("BOTTOMRIGHT", Handler.Latency, "BOTTOMRIGHT", 0, 0)
	end,

	-- Show mail
	UseMail = true,
		MailPlace = { "TOPRIGHT", 30, 20 },
		MailSize = { 43, 32 },
		MailTexture = getPath("icon-mail"),
		MailTexturePlace = { "CENTER", 0, 0 }, 
		MailTextureSize = { 66, 66 },
		MailTextureDrawLayer = { "ARTWORK", 1 },
		MailTextureRotation = degreesToRadians(7.5),

	UseGroupFinderEye = true, 
		GroupFinderEyePlace = { "CENTER", math.cos(230*math_pi/180) * (220 *256/288/2 + 20), math.sin(230*math_pi/180) * (220 *256/288/2 + 20) }, 
		GroupFinderEyeSize = { 56, 56 }, 
		GroupFinderEyeColor = { Colors.ui.stone[1], Colors.ui.stone[2], Colors.ui.stone[3] }, 
		--GroupFinderEyeTexture = [[Interface\LFGFrame\BattlenetWorking0]],
		GroupFinderQueueStatusPlace = { "TOPRIGHT", QueueStatusMinimapButton, "BOTTOMLEFT", 16, 16 },

		UseGroupFinderEyeBackdrop = true, 
			GroupFinderEyeBackdropSize = { 44, 44 },
			GroupFinderEyeBackdropTexture = getPath("minimap-border"),
			GroupFinderEyeBackdropColor = { Colors.ui.stone[1], Colors.ui.stone[2], Colors.ui.stone[3] },
	

	AutoDisable = {
		SexyMap = true
	}
}

-- Core Tooltips
local TooltipStyling = {
	TooltipPlace = { "TOPRIGHT", "Minimap", "TOPLEFT", -48, -26 }, 
	TooltipStatusBarTexture = getPath("statusbar-power"), 
	TooltipBackdrop = {
		bgFile = [[Interface\ChatFrame\ChatFrameBackground]], tile = false, 
		edgeFile = getPath("border-tooltip-blizzcompatible"), edgeSize = 32, 
		insets = { top = 2.5, bottom = 2.5, left = 2.5, right = 2.5 }
	},
	TooltipBackdropColor = { .05, .05, .05, .85 },
	TooltipBackdropBorderColor = { 1, 1, 1, 1 },
}

-- UnitFrame: Player
local OFFSET_BOTTOM = 330
local UnitFramePlayer = { 
	Place = { "BOTTOMRIGHT", "UICenter", "BOTTOM", -210, OFFSET_BOTTOM },
	Size = { 300, 74 },
	
	UseBorderBackdrop = true,
		BorderFramePlace = { "CENTER", 0, 0 },
		BorderFrameSize = { 300 + 46, 74 + 46 },
		BorderFrameBackdrop = { edgeFile = getPath("border-tooltip"), edgeSize = 32 },
		BorderFrameBackdropColor = { 0, 0, 0, 0 },
		BorderFrameBackdropBorderColor = { Colors.ui.stone[1], Colors.ui.stone[2], Colors.ui.stone[3] },

	HealthPlace = { "TOPLEFT", 0, 0 }, 
		HealthSize = { 300, 52 },  -- health size
		HealthType = "StatusBar", -- health type
		HealthBarTexture = getPath("statusbar-normal"), -- only called when non-progressive frames are used
		HealthBarOrientation = "RIGHT", -- bar orientation
		HealthBarSparkMap = nil,
		HealthSmoothingMode = "bezier-fast-in-slow-out", -- smoothing method
		HealthSmoothingFrequency = .5, -- speed of the smoothing method
		HealthColorTapped = false, -- color tap denied units 
		HealthColorDisconnected = false, -- color disconnected units
		HealthColorClass = true, -- color players by class 
		HealthColorReaction = false, -- color NPCs by their reaction standing with us
		HealthColorHealth = false, -- color anything else in the default health color
		HealthFrequentUpdates = true, -- listen to frequent health events for more accurate updates

		UseHealthBackdrop = true,
			HealthBackdropPlace = { "TOPLEFT", 0, 0 },
			HealthBackdropSize = { 300, 52 },
			HealthBackdropTexture = getPath("statusbar-backdrop"), 
			HealthBackdropDrawLayer = { "BACKGROUND", -2 },

		UseHealthForeground = true, 
			HealthForegroundPlace = { "TOPLEFT", 0, 0 },
			HealthForegroundSize = { 300, 52 },
			HealthForegroundTexture = getPath("statusbar-normal-overlay"), 
			HealthForegroundDrawLayer = { "BORDER", 1 },

		UseHealthValue = true, 
			HealthValuePlace = { "RIGHT", -10, 0 },
			HealthValueDrawLayer = { "OVERLAY", 1 },
			HealthValueJustifyH = "CENTER", 
			HealthValueJustifyV = "MIDDLE", 
			HealthValueFont = Fonts(15, true),
			HealthValueColor = { Colors.offwhite[1], Colors.offwhite[2], Colors.offwhite[3], .75 },
	
	UseAbsorbBar = true,
		AbsorbBarPlace = { "TOPLEFT", 0, 0 },
		AbsorbSize = { 300, 52 },
		AbsorbBarOrientation = "LEFT",
		AbsorbBarTexture = getPath("statusbar-normal"),
		AbsorbBarColor = { 1, 1, 1, .25 },

		UseAbsorbValue = true, 
			AbsorbValuePlaceFunction = function(self) return "RIGHT", self.Health.Value, "LEFT", -13, 0 end, 
			AbsorbValueDrawLayer = { "OVERLAY", 1 }, 
			AbsorbValueFont = Fonts(15, true),
			AbsorbValueJustifyH = "CENTER", 
			AbsorbValueJustifyV = "MIDDLE",
			AbsorbValueColor = { Colors.offwhite[1], Colors.offwhite[2], Colors.offwhite[3], .75 },

	UsePowerBar = true,
		PowerPlace = { "BOTTOMRIGHT", 0, 0 },
		PowerSize = { 300, 23 },
		PowerType = "StatusBar",
		PowerBarTexture = getPath("statusbar-power"),
		PowerBarTexCoord = { 0, 1, 0, 1 },
		PowerBarOrientation = "RIGHT",
		PowerBarSmoothingMode = "bezier-fast-in-slow-out",
		PowerBarSmoothingFrequency = .35,

		UsePowerBackground = true,
			PowerBackgroundPlace = { "BOTTOMRIGHT", 0, 0 }, 
			PowerBackgroundSize = { 300, 23 }, 
			PowerBackgroundTexture = getPath("statusbar-backdrop"),
			PowerBackgroundDrawLayer = { "BACKGROUND", -2 },
			PowerBackgroundColor = { 1, 1, 1, 1 },

		UsePowerForeground = true,
			PowerForegroundPlace = { "BOTTOMRIGHT", 0, 0 }, 
			PowerForegroundSize = { 300, 23 }, 
			PowerForegroundTexture = getPath("statusbar-resource-overlay"), 
			PowerForegroundDrawLayer = { "BORDER", 1 },
	
		UsePowerValue = true, 
			PowerValuePlace = { "CENTER", 0, .5 },
			PowerValueDrawLayer = { "OVERLAY", 1 },
			PowerValueJustifyH = "CENTER", 
			PowerValueJustifyV = "MIDDLE", 
			PowerValueFont = Fonts(12, true),
			PowerValueColor = { Colors.offwhite[1], Colors.offwhite[2], Colors.offwhite[3], .75 },
	
	UseCastBar = true,
		CastBarPlace = { "TOPLEFT", 0, 0 },
		CastBarSize = { 300, 52 },
		CastBarOrientation = "RIGHT", 
		CastBarSmoothingMode = "bezier-fast-in-slow-out", 
		CastBarSmoothingFrequency = .15,
		CastBarTexture = getPath("statusbar-normal"), 
		CastBarColor = { 1, 1, 1, .15 }, 

	UseCombatIndicator = true, 
		CombatIndicatorPlace = { "CENTER", 0, 12 },
		CombatIndicatorSize = { 56,56 },
		CombatIndicatorTexture = getPath("icons-combat-swords"),
		CombatIndicatorDrawLayer = {"OVERLAY", -2 },
		CombatIndicatorColor = { 1, 1, 1, 1 }, 
		CombatIndicatorGlowPlace = { "CENTER", 0, 12 },
		CombatIndicatorGlowSize = { 56,56 },
		CombatIndicatorGlowTexture = getPath("icons-combat-swords"), 
		CombatIndicatorGlowDrawLayer = { "OVERLAY", -1 }, 
		CombatIndicatorGlowColor = { 0, 0, 0, 0 }, 

	UseDebuffs = true, 
		DebuffFramePlace = { "TOPRIGHT", -(300 + 16), 1 },
		DebuffFrameSize = { 38*7 + 6*(7-1), 38*3 + 6*2 },
		DebuffSize = 38, -- aurasize
		DebuffSpaceH = 6, -- horizontal spacing between auras
		DebuffSpaceV = 6, -- vertical spacing between auras
		DebuffMax = 21, -- max number of auras
		DebuffGrowthX = "LEFT", -- horizontal growth of auras
		DebuffGrowthY = "DOWN", -- vertical growth of auras
		DebuffFilterFunc = Auras.DebuffFilter, -- debuff specific filter function
		DebuffTooltipDefaultPosition = nil,
		DebuffTooltipPoint = "BOTTOMLEFT",
		DebuffTooltipAnchor = nil,
		DebuffTooltipRelPoint = "TOPLEFT",
		DebuffTooltipOffsetX = 8,
		DebuffTooltipOffsetY = 16,
		ShowDebuffCooldownSpirals = false, -- show cooldown spirals on auras
		ShowDebuffCooldownTime = true, -- show time text on auras
		DebuffIconPlace = { "CENTER", 0, 0 },
		DebuffIconSize = { 38 - 6, 38 - 6 },
		DebuffIconTexCoord = { 5/64, 59/64, 5/64, 59/64 }, -- aura icon tex coords
		DebuffCountPlace = { "BOTTOMRIGHT", 2, -2 },
		DebuffCountFont = Fonts(11, true),
		DebuffTimePlace = { "CENTER", 0, 0 },
		DebuffTimeFont = Fonts(14, true),
		DebuffBorderFramePlace = { "CENTER", 0, 0 }, 
		DebuffBorderFrameSize = { 38 + 14, 38 + 14 },
		DebuffBorderBackdrop = { edgeFile = getPath("border-tooltip"), edgeSize = 16 },
		DebuffBorderBackdropColor = { 0, 0, 0, 0 },
		DebuffBorderBackdropBorderColor = { Colors.ui.stone[1], Colors.ui.stone[2], Colors.ui.stone[3] },

	UseBuffs = true, 
		BuffFramePlace = { "BOTTOMRIGHT", 1, - ((38*2 + 6*1) + 16) },
		BuffFrameSize = { 38*7 + 6*(7-1), 38*2 + 6*1 },
		BuffSize = 38, -- aurasize
		BuffSpaceH = 6, -- horizontal spacing between auras
		BuffSpaceV = 6, -- vertical spacing between auras
		BuffMax = 14, -- max number of auras
		BuffGrowthX = "LEFT", -- horizontal growth of auras
		BuffGrowthY = "DOWN", -- vertical growth of auras
		BuffFilterFunc = Auras.BuffFilter, -- debuff specific filter function
		BuffTooltipDefaultPosition = nil,
		BuffTooltipPoint = "BOTTOMLEFT",
		BuffTooltipAnchor = nil,
		BuffTooltipRelPoint = "TOPLEFT",
		BuffTooltipOffsetX = 8,
		BuffTooltipOffsetY = 16,
		ShowBuffCooldownSpirals = false, -- show cooldown spirals on auras
		ShowBuffCooldownTime = true, -- show time text on auras

		BuffIconPlace = { "CENTER", 0, 0 },
		BuffIconSize = { 38 - 6, 38 - 6 },
		BuffIconTexCoord = { 5/64, 59/64, 5/64, 59/64 }, -- aura icon tex coords
		BuffCountPlace = { "BOTTOMRIGHT", 2, -2 },
		BuffCountFont = Fonts(11, true),
		BuffTimePlace = { "CENTER", 0, 0 },
		BuffTimeFont = Fonts(14, true),
		BuffBorderFramePlace = { "CENTER", 0, 0 }, 
		BuffBorderFrameSize = { 38 + 14, 38 + 14 },
		BuffBorderBackdrop = { edgeFile = getPath("border-tooltip"), edgeSize = 16 },
		BuffBorderBackdropColor = { 0, 0, 0, 0 },
		BuffBorderBackdropBorderColor = { Colors.ui.stone[1], Colors.ui.stone[2], Colors.ui.stone[3] },

		-- just until buff/Debuff specific is implemented
		AuraIconPlace = { "CENTER", 0, 0 },
		AuraIconSize = { 38 - 6, 38 - 6 },
		AuraIconTexCoord = { 5/64, 59/64, 5/64, 59/64 }, -- aura icon tex coords
		AuraCountPlace = { "BOTTOMRIGHT", 2, -2 },
		AuraCountFont = Fonts(11, true),
		AuraTimePlace = { "CENTER", 0, 0 },
		AuraTimeFont = Fonts(14, true),
		AuraBorderFramePlace = { "CENTER", 0, 0 }, 
		AuraBorderFrameSize = { 38 + 14, 38 + 14 },
		AuraBorderBackdrop = { edgeFile = getPath("border-tooltip"), edgeSize = 16 },
		AuraBorderBackdropColor = { 0, 0, 0, 0 },
		AuraBorderBackdropBorderColor = { Colors.ui.stone[1], Colors.ui.stone[2], Colors.ui.stone[3] },

	UseName = true, 
		NamePlace = { "LEFT", 16, 10 },
		NameSize = { 160, 15 }, 
		NameFont = Fonts(14, true),
		NameColor = { Colors.offwhite[1], Colors.offwhite[2], Colors.offwhite[3], .75 },
		NameDrawLayer = { "OVERLAY", 1 }, 
		NameDrawJustifyH = "LEFT", 
		NameDrawJustifyV = "MIDDLE"


}

-- UnitFrame: PlayerHUD (combo points and castbar)
local UnitFramePlayerHUD = {

	Size = { 264, 34 }, 
	Place = { "BOTTOM", "UICenter", "BOTTOM", 0, 300 }, 
	IgnoreMouseOver = true,  

	UseCastBar = true, 
		CastBarPlace = { "BOTTOM", 0, 0 },
		CastBarSize = { 264, 26 }, 
		CastBarTexture = getPath("statusbar-power"),
		CastBarColor = { 70/255, 255/255, 131/255, .69 }, 
		CastBarOrientation = "RIGHT",

		UseCastBarBorderFrame = true, 
			CastBarBorderFramePlace = { "CENTER", 0, 0 }, 
			CastBarBorderFrameSize = { 264 + 46, 26 + 46 }, 
			CastBarBorderFrameBackdrop = { edgeFile = getPath("border-tooltip"), edgeSize = 32 }, 
			CastBarBorderFrameBackdropColor = { 0, 0, 0, 0 }, 
			CastBarBorderFrameBackdropBorderColor = { Colors.ui.stone[1], Colors.ui.stone[2], Colors.ui.stone[3] }, 

		UseCastBarBackground = true, 
			CastBarBackgroundPlace = { "CENTER", 0, 0 }, 
			CastBarBackgroundSize = { 264, 26 },
			CastBarBackgroundTexture = getPath("statusbar-backdrop"), 
			CastBarBackgroundDrawLayer = { "BACKGROUND", 1 },
			CastBarBackgroundColor = { Colors.ui.stone[1], Colors.ui.stone[2], Colors.ui.stone[3] },
			
		UseCastBarValue = true, 
			CastBarValuePlace = { "CENTER", 0, 0 },
			CastBarValueFont = Fonts(14, true),
			CastBarValueDrawLayer = { "OVERLAY", 1 },
			CastBarValueJustifyH = "CENTER",
			CastBarValueJustifyV = "MIDDLE",
			CastBarValueColor = { Colors.highlight[1], Colors.highlight[2], Colors.highlight[3], .5 },
	
		UseCastBarName = true, 
			CastBarNamePlace = { "TOP", 0, -(10 + 26) },
			CastBarNameFont = Fonts(12, true),
			CastBarNameDrawLayer = { "OVERLAY", 1 },
			CastBarNameJustifyH = "CENTER",
			CastBarNameJustifyV = "MIDDLE",
			CastBarNameColor = { Colors.highlight[1], Colors.highlight[2], Colors.highlight[3], .5 },
	
	UseClassPower = true, 
		ClassPowerPlace = { "BOTTOM", 0, 0 }, 
		ClassPowerSize = { 2,2 }, 
		ClassPowerHideWhenUnattackable = false, 
		ClassPowerMaxComboPoints = 5, 
		ClassPowerHideWhenNoTarget = true, 
		ClassPowerAlphaWhenEmpty = .95,
		ClassPowerAlphaWhenOutOfCombat = 1,

		ClassPowerPostCreatePoint = function(element, id, point)
			point:SetOrientation("RIGHT") 
			point:SetStatusBarTexture(getPath("statusbar-resource"))

			point.slotTexture:SetTexture(getPath("statusbar-backdrop"))

			point.Border = point:CreateFrame("Frame", nil, point)
			point.Border:SetPoint("TOPLEFT", -23*3/4, 23*3/4)
			point.Border:SetPoint("BOTTOMRIGHT", 23*3/4, -23*3/4)
			point.Border:SetFrameLevel(point:GetFrameLevel() + 8)
			point.Border:SetBackdrop({
				edgeFile = getPath("border-tooltip"), 
				edgeSize = 32*3/4
			})
			point.Border:SetBackdropBorderColor(Colors.ui.stone[1], Colors.ui.stone[2], Colors.ui.stone[3])
		
		end,

		ClassPowerPostUpdate = function(element, unit, min, max, newMax, powerType)

			--	Class Powers available in Legion/BfA: 
			--------------------------------------------------------------------------------- 
			-- 	* Arcane Charges 	Generated points. 5 cap. 0 baseline.
			--	* Chi: 				Generated points. 5 cap, 6 if talented, 0 baseline.
			--	* Combo Points: 	Fast generated points. 5 cap, 6-10 if talented, 0 baseline.
			--	* Holy Power: 		Fast generated points. 5 cap, 0 baseline.
			--	* Soul Shards: 		Slowly generated points. 5 cap, 1 point baseline.
			--	* Stagger: 			Generated points. 3 cap. 3 baseline. 
			--	* Runes: 			Fast refilling points. 6 cap, 6 baseline.
		
			local numPoints = (powerType == "STAGGER") and 3 or (powerType == "RUNES") and 6 or 5
			if (numPoints ~= element.powerStyle) then 
		
				local space = 10
				local size = (264 - (numPoints-1)*space) / numPoints
		
				-- resize points
				for i = 1, #element do 
					local point = element[i]
					point:Place("LEFT", (i-1)*(size+space), 0)
					point:SetSize(size, 14)
		
					if (i > numPoints) then 
						point:Hide()
					end 
				end 
		
				-- reposition and resize frame
				element:Place("BOTTOM", 0, 46)
				element:SetSize(264, 14)
		
		
				-- Store the element's full stylestring
				element.powerStyle = numPoints
			end 
		end 
}

-- UnitFrame: Target
local UnitFrameTarget = { 
	Place = { "BOTTOMLEFT", "UICenter", "BOTTOM", 210, OFFSET_BOTTOM },
	Size = { 300, 74 },
	
	UseBorderBackdrop = true,
		BorderFramePlace = { "CENTER", 0, 0 },
		BorderFrameSize = { 300 + 46, 74 + 46 },
		BorderFrameBackdrop = { edgeFile = getPath("border-tooltip"), edgeSize = 32 },
		BorderFrameBackdropColor = { 0, 0, 0, 0 },
		BorderFrameBackdropBorderColor = { Colors.ui.stone[1], Colors.ui.stone[2], Colors.ui.stone[3] },

	HealthPlace = { "TOPLEFT", 0, 0 }, 
		HealthSize = { 300, 52 },  -- health size
		HealthType = "StatusBar", -- health type
		HealthBarTexture = getPath("statusbar-normal"), -- only called when non-progressive frames are used
		HealthBarOrientation = "LEFT", -- bar orientation
		HealthBarSetFlippedHorizontally = true, 
		HealthBarSparkMap = nil,
		HealthSmoothingMode = "bezier-fast-in-slow-out", -- smoothing method
		HealthSmoothingFrequency = .5, -- speed of the smoothing method
		HealthColorTapped = true, -- color tap denied units 
		HealthColorDisconnected = true, -- color disconnected units
		HealthColorClass = true, -- color players by class 
		HealthColorReaction = true, -- color NPCs by their reaction standing with us
		HealthColorHealth = false, -- color anything else in the default health color
		HealthFrequentUpdates = true, -- listen to frequent health events for more accurate updates

		UseHealthBackdrop = true,
			HealthBackdropPlace = { "TOPLEFT", 0, 0 },
			HealthBackdropSize = { 300, 52 },
			HealthBackdropTexture = getPath("statusbar-backdrop"), 
			HealthBackdropDrawLayer = { "BACKGROUND", -2 },

		UseHealthForeground = true, 
			HealthForegroundPlace = { "TOPLEFT", 0, 0 },
			HealthForegroundSize = { 300, 52 },
			HealthForegroundTexture = getPath("statusbar-normal-overlay"), 
			HealthForegroundDrawLayer = { "BORDER", 1 },

		UseHealthValue = true, 
			HealthValuePlace = { "LEFT", 10, 0 },
			HealthValueDrawLayer = { "OVERLAY", 1 },
			HealthValueJustifyH = "CENTER", 
			HealthValueJustifyV = "MIDDLE", 
			HealthValueFont = Fonts(15, true),
			HealthValueColor = { Colors.offwhite[1], Colors.offwhite[2], Colors.offwhite[3], .75 },
	
	UseAbsorbBar = true,
		AbsorbBarPlace = { "TOPLEFT", 0, 0 },
		AbsorbSize = { 300, 52 },
		AbsorbBarOrientation = "RIGHT",
		AbsorbBarSetFlippedHorizontally = true, 
		AbsorbBarTexture = getPath("statusbar-normal"),
		AbsorbBarColor = { 1, 1, 1, .25 },

		UseAbsorbValue = true, 
			AbsorbValuePlaceFunction = function(self) return "LEFT", self.Health.Value, "RIGHT", 13, 0 end, 
			AbsorbValueDrawLayer = { "OVERLAY", 1 }, 
			AbsorbValueFont = Fonts(15, true),
			AbsorbValueJustifyH = "CENTER", 
			AbsorbValueJustifyV = "MIDDLE",
			AbsorbValueColor = { Colors.offwhite[1], Colors.offwhite[2], Colors.offwhite[3], .75 },

	UsePowerBar = true,
		PowerPlace = { "BOTTOMRIGHT", 0, 0 },
		PowerSize = { 300, 23 },
		PowerType = "StatusBar",
		PowerBarTexture = getPath("statusbar-power"),
		PowerBarTexCoord = { 0, 1, 0, 1 },
		PowerBarOrientation = "LEFT",
		PowerBarSmoothingMode = "bezier-fast-in-slow-out",
		PowerBarSmoothingFrequency = .35,

		UsePowerBackground = true,
			PowerBackgroundPlace = { "BOTTOMRIGHT", 0, 0 }, 
			PowerBackgroundSize = { 300, 23 }, 
			PowerBackgroundTexture = getPath("statusbar-backdrop"),
			PowerBackgroundDrawLayer = { "BACKGROUND", -2 },
			PowerBackgroundColor = { 1, 1, 1, 1 },

		UsePowerForeground = true,
			PowerForegroundPlace = { "BOTTOMRIGHT", 0, 0 }, 
			PowerForegroundSize = { 300, 23 }, 
			PowerForegroundTexture = getPath("statusbar-resource-overlay"), 
			PowerForegroundDrawLayer = { "BORDER", 1 },
	
		UsePowerValue = true, 
			PowerValuePlace = { "CENTER", 0, .5 },
			PowerValueDrawLayer = { "OVERLAY", 1 },
			PowerValueJustifyH = "CENTER", 
			PowerValueJustifyV = "MIDDLE", 
			PowerValueFont = Fonts(12, true),
			PowerValueColor = { Colors.offwhite[1], Colors.offwhite[2], Colors.offwhite[3], .75 },
	
	UseCastBar = true,
		CastBarPlace = { "TOPLEFT", 0, 0 },
		CastBarSize = { 300, 52 },
		CastBarOrientation = "LEFT", 
		CastBarSmoothingMode = "bezier-fast-in-slow-out", 
		CastBarSmoothingFrequency = .15,
		CastBarTexture = getPath("statusbar-normal"), 
		CastBarColor = { 1, 1, 1, .15 }, 

	UseCombatIndicator = true, 
		CombatIndicatorPlace = { "CENTER", 0, 12 },
		CombatIndicatorSize = { 56,56 },
		CombatIndicatorTexture = getPath("icons-combat-swords"),
		CombatIndicatorDrawLayer = {"OVERLAY", -2 },
		CombatIndicatorColor = { 1, 1, 1, 1 }, 
		CombatIndicatorGlowPlace = { "CENTER", 0, 12 },
		CombatIndicatorGlowSize = { 56,56 },
		CombatIndicatorGlowTexture = getPath("icons-combat-swords"), 
		CombatIndicatorGlowDrawLayer = { "OVERLAY", -1 }, 
		CombatIndicatorGlowColor = { 0, 0, 0, 0 }, 

	UseBuffs = true, 
		BuffFramePlace = { "TOPLEFT", 300 + 16, 1 },
		BuffFrameSize = { 38*7 + 6*(7-1), 38*3 + 6*2 },
		BuffSize = 38, -- aurasize
		BuffSpaceH = 6, -- horizontal spacing between auras
		BuffSpaceV = 6, -- vertical spacing between auras
		BuffMax = 21, -- max number of auras
		BuffGrowthX = "RIGHT", -- horizontal growth of auras
		BuffGrowthY = "DOWN", -- vertical growth of auras
		BuffFilterFunc = Auras.BuffFilter, -- debuff specific filter function
		BuffTooltipDefaultPosition = nil,
		BuffTooltipPoint = "BOTTOMLEFT",
		BuffTooltipAnchor = nil,
		BuffTooltipRelPoint = "TOPLEFT",
		BuffTooltipOffsetX = 8,
		BuffTooltipOffsetY = 16,
		ShowBuffCooldownSpirals = false, -- show cooldown spirals on auras
		ShowBuffCooldownTime = true, -- show time text on auras
		BuffIconPlace = { "CENTER", 0, 0 },
		BuffIconSize = { 38 - 6, 38 - 6 },
		BuffIconTexCoord = { 5/64, 59/64, 5/64, 59/64 }, -- aura icon tex coords
		BuffCountPlace = { "BOTTOMRIGHT", 2, -2 },
		BuffCountFont = Fonts(11, true),
		BuffTimePlace = { "CENTER", 0, 0 },
		BuffTimeFont = Fonts(14, true),
		BuffBorderFramePlace = { "CENTER", 0, 0 }, 
		BuffBorderFrameSize = { 38 + 14, 38 + 14 },
		BuffBorderBackdrop = { edgeFile = getPath("border-tooltip"), edgeSize = 16 },
		BuffBorderBackdropColor = { 0, 0, 0, 0 },
		BuffBorderBackdropBorderColor = { Colors.ui.stone[1], Colors.ui.stone[2], Colors.ui.stone[3] },

	UseDebuffs = true, 
		DebuffFramePlace = { "BOTTOMLEFT", -1, - ((38*2 + 6*1) + 16) },
		DebuffFrameSize = { 38*7 + 6*(7-1), 38*2 + 6*1 },
		DebuffSize = 38, -- aurasize
		DebuffSpaceH = 6, -- horizontal spacing between auras
		DebuffSpaceV = 6, -- vertical spacing between auras
		DebuffMax = 14, -- max number of auras
		DebuffGrowthX = "RIGHT", -- horizontal growth of auras
		DebuffGrowthY = "DOWN", -- vertical growth of auras
		DebuffFilterFunc = Auras.DebuffFilter, -- debuff specific filter function
		DebuffTooltipDefaultPosition = nil,
		DebuffTooltipPoint = "BOTTOMLEFT",
		DebuffTooltipAnchor = nil,
		DebuffTooltipRelPoint = "TOPLEFT",
		DebuffTooltipOffsetX = 8,
		DebuffTooltipOffsetY = 16,
		ShowDebuffCooldownSpirals = false, -- show cooldown spirals on auras
		ShowDebuffCooldownTime = true, -- show time text on auras
		DebuffIconPlace = { "CENTER", 0, 0 },
		DebuffIconSize = { 38 - 6, 38 - 6 },
		DebuffIconTexCoord = { 5/64, 59/64, 5/64, 59/64 }, -- aura icon tex coords
		DebuffCountPlace = { "BOTTOMRIGHT", 2, -2 },
		DebuffCountFont = Fonts(11, true),
		DebuffTimePlace = { "CENTER", 0, 0 },
		DebuffTimeFont = Fonts(14, true),
		DebuffBorderFramePlace = { "CENTER", 0, 0 }, 
		DebuffBorderFrameSize = { 38 + 14, 38 + 14 },
		DebuffBorderBackdrop = { edgeFile = getPath("border-tooltip"), edgeSize = 16 },
		DebuffBorderBackdropColor = { 0, 0, 0, 0 },
		DebuffBorderBackdropBorderColor = { Colors.ui.stone[1], Colors.ui.stone[2], Colors.ui.stone[3] },

		-- just until buff/Debuff specific is implemented
		AuraIconPlace = { "CENTER", 0, 0 },
		AuraIconSize = { 38 - 6, 38 - 6 },
		AuraIconTexCoord = { 5/64, 59/64, 5/64, 59/64 }, -- aura icon tex coords
		AuraCountPlace = { "BOTTOMRIGHT", 2, -2 },
		AuraCountFont = Fonts(11, true),
		AuraTimePlace = { "CENTER", 0, 0 },
		AuraTimeFont = Fonts(14, true),
		AuraBorderFramePlace = { "CENTER", 0, 0 }, 
		AuraBorderFrameSize = { 38 + 14, 38 + 14 },
		AuraBorderBackdrop = { edgeFile = getPath("border-tooltip"), edgeSize = 16 },
		AuraBorderBackdropColor = { 0, 0, 0, 0 },
		AuraBorderBackdropBorderColor = { Colors.ui.stone[1], Colors.ui.stone[2], Colors.ui.stone[3] },
	
	UseName = true, 
		NamePlace = { "RIGHT", -16, 10 },
		NameSize = { 160, 15 }, 
		NameFont = Fonts(14, true),
		NameColor = { Colors.offwhite[1], Colors.offwhite[2], Colors.offwhite[3], .75 },
		NameDrawLayer = { "OVERLAY", 1 }, 
		NameDrawJustifyH = "RIGHT", 
		NameDrawJustifyV = "MIDDLE"


}

-- UnitFrame: Target of Target
local UnitFrameToT = {
	Place = { "BOTTOMLEFT", "UICenter", "BOTTOM", 210 + 300/2 + 10, OFFSET_BOTTOM + 74 + 22 },
	Size = { 300/2 - 10, 74/2 },
	
	UseBorderBackdrop = true,
		BorderFramePlace = { "CENTER", 0, 0 },
		BorderFrameSize = { 300/2 - 10 + 46, 74/2 + 46 },
		BorderFrameBackdrop = { edgeFile = getPath("border-tooltip"), edgeSize = 32 },
		BorderFrameBackdropColor = { 0, 0, 0, 0 },
		BorderFrameBackdropBorderColor = { Colors.ui.stone[1], Colors.ui.stone[2], Colors.ui.stone[3] },

		HealthPlace = { "TOPLEFT", 0, 0 }, 
		HealthSize = { 300/2 - 10, 74/2 },  -- health size
		HealthType = "StatusBar", -- health type
		HealthBarTexture = getPath("statusbar-normal"), -- only called when non-progressive frames are used
		HealthBarOrientation = "LEFT", -- bar orientation
		HealthBarSetFlippedHorizontally = true, 
		HealthBarSparkMap = nil,
		HealthSmoothingMode = "bezier-fast-in-slow-out", -- smoothing method
		HealthSmoothingFrequency = .5, -- speed of the smoothing method
		HealthColorTapped = true, -- color tap denied units 
		HealthColorDisconnected = true, -- color disconnected units
		HealthColorClass = true, -- color players by class 
		HealthColorReaction = true, -- color NPCs by their reaction standing with us
		HealthColorHealth = false, -- color anything else in the default health color
		HealthFrequentUpdates = true, -- listen to frequent health events for more accurate updates

		UseHealthBackdrop = true,
			HealthBackdropPlace = { "TOPLEFT", 0, 0 },
			HealthBackdropSize = { 300/2 - 10, 74/2 },
			HealthBackdropTexture = getPath("statusbar-backdrop"), 
			HealthBackdropDrawLayer = { "BACKGROUND", -2 },

		UseHealthForeground = true, 
			HealthForegroundPlace = { "TOPLEFT", 0, 0 },
			HealthForegroundSize = { 300/2 - 10, 74/2 },
			HealthForegroundTexture = getPath("statusbar-normal-overlay"), 
			HealthForegroundDrawLayer = { "BORDER", 1 },

		UseHealthValue = true, 
			HealthValuePlace = { "LEFT", 10, 0 },
			HealthValueDrawLayer = { "OVERLAY", 1 },
			HealthValueJustifyH = "LEFT", 
			HealthValueJustifyV = "MIDDLE", 
			HealthValueFont = Fonts(11, true),
			HealthValueColor = { Colors.offwhite[1], Colors.offwhite[2], Colors.offwhite[3], .75 },
			HealthValueOverride = false, 
			HealthShowPercent = true, 
	
	UseAbsorbBar = true,
		AbsorbBarPlace = { "TOPLEFT", 0, 0 },
		AbsorbSize = { 300/2 - 10, 74/2 },
		AbsorbBarOrientation = "RIGHT",
		AbsorbBarSetFlippedHorizontally = true, 
		AbsorbBarTexture = getPath("statusbar-normal"),
		AbsorbBarColor = { 1, 1, 1, .25 },


	UseCastBar = true,
		CastBarPlace = { "TOPLEFT", 0, 0 },
		CastBarSize = { 300/2 - 10, 74/2 },
		CastBarOrientation = "LEFT", 
		CastBarSmoothingMode = "bezier-fast-in-slow-out", 
		CastBarSmoothingFrequency = .15,
		CastBarTexture = getPath("statusbar-normal"), 
		CastBarColor = { 1, 1, 1, .15 }, 

	UseName = true, 
		NamePlace = { "RIGHT", -10, 0 },
		NameSize = { 86, 15 }, 
		NameFont = Fonts(11, true),
		NameColor = { Colors.offwhite[1], Colors.offwhite[2], Colors.offwhite[3], .75 },
		NameDrawLayer = { "OVERLAY", 1 }, 
		NameDrawJustifyH = "RIGHT", 
		NameDrawJustifyV = "MIDDLE"
}

-- UnitFrame: Pet
local UnitFramePet = {
	Place = { "BOTTOMRIGHT", "UICenter", "BOTTOM", -(210 + 300/2 + 10), OFFSET_BOTTOM + 74 + 22 },
	Size = { 300/2 - 10, 74/2 },
	
	UseBorderBackdrop = true,
		BorderFramePlace = { "CENTER", 0, 0 },
		BorderFrameSize = { 300/2 - 10 + 46, 74/2 + 46 },
		BorderFrameBackdrop = { edgeFile = getPath("border-tooltip"), edgeSize = 32 },
		BorderFrameBackdropColor = { 0, 0, 0, 0 },
		BorderFrameBackdropBorderColor = { Colors.ui.stone[1], Colors.ui.stone[2], Colors.ui.stone[3] },

		HealthPlace = { "TOPLEFT", 0, 0 }, 
		HealthSize = { 300/2 - 10, 74/2 },  -- health size
		HealthType = "StatusBar", -- health type
		HealthBarTexture = getPath("statusbar-normal"), -- only called when non-progressive frames are used
		HealthBarOrientation = "RIGHT", -- bar orientation
		HealthBarSetFlippedHorizontally = false, 
		HealthBarSparkMap = nil,
		HealthSmoothingMode = "bezier-fast-in-slow-out", -- smoothing method
		HealthSmoothingFrequency = .5, -- speed of the smoothing method
		HealthColorTapped = true, -- color tap denied units 
		HealthColorDisconnected = true, -- color disconnected units
		HealthColorClass = true, -- color players by class 
		HealthColorPetAsPlayer = true, -- color your pet as you 
		HealthColorReaction = true, -- color NPCs by their reaction standing with us
		HealthColorHealth = false, -- color anything else in the default health color
		HealthFrequentUpdates = true, -- listen to frequent health events for more accurate updates

		UseHealthBackdrop = true,
			HealthBackdropPlace = { "TOPLEFT", 0, 0 },
			HealthBackdropSize = { 300/2 - 10, 74/2 },
			HealthBackdropTexture = getPath("statusbar-backdrop"), 
			HealthBackdropDrawLayer = { "BACKGROUND", -2 },

		UseHealthForeground = true, 
			HealthForegroundPlace = { "TOPLEFT", 0, 0 },
			HealthForegroundSize = { 300/2 - 10, 74/2 },
			HealthForegroundTexture = getPath("statusbar-normal-overlay"), 
			HealthForegroundDrawLayer = { "BORDER", 1 },

		UseHealthValue = true, 
			HealthValuePlace = { "RIGHT", -10, 0 },
			HealthValueDrawLayer = { "OVERLAY", 1 },
			HealthValueJustifyH = "LEFT", 
			HealthValueJustifyV = "MIDDLE", 
			HealthValueFont = Fonts(11, true),
			HealthValueColor = { Colors.offwhite[1], Colors.offwhite[2], Colors.offwhite[3], .75 },
			HealthValueOverride = false, 
			HealthShowPercent = true, 
	
	UseAbsorbBar = true,
		AbsorbBarPlace = { "TOPLEFT", 0, 0 },
		AbsorbSize = { 300/2 - 10, 74/2 },
		AbsorbBarOrientation = "LEFT",
		AbsorbBarSetFlippedHorizontally = false, 
		AbsorbBarTexture = getPath("statusbar-normal"),
		AbsorbBarColor = { 1, 1, 1, .25 },


	UseCastBar = true,
		CastBarPlace = { "TOPLEFT", 0, 0 },
		CastBarSize = { 300/2 - 10, 74/2 },
		CastBarOrientation = "RIGHT", 
		CastBarSmoothingMode = "bezier-fast-in-slow-out", 
		CastBarSmoothingFrequency = .15,
		CastBarTexture = getPath("statusbar-normal"), 
		CastBarColor = { 1, 1, 1, .15 }, 

	UseName = true, 
		NamePlace = { "LEFT", 10, 0 },
		NameSize = { 86, 15 }, 
		NameFont = Fonts(11, true),
		NameColor = { Colors.offwhite[1], Colors.offwhite[2], Colors.offwhite[3], .75 },
		NameDrawLayer = { "OVERLAY", 1 }, 
		NameDrawJustifyH = "LEFT", 
		NameDrawJustifyV = "MIDDLE"
}

CogWheel("LibDB"):NewDatabase(ADDON..": Layout [Core]", Core)
CogWheel("LibDB"):NewDatabase(ADDON..": Layout [ActionBarMain]", ActionBarMain)
CogWheel("LibDB"):NewDatabase(ADDON..": Layout [BlizzardChatFrames]", BlizzardChatFrames)
CogWheel("LibDB"):NewDatabase(ADDON..": Layout [BlizzardMicroMenu]", BlizzardMicroMenu)
CogWheel("LibDB"):NewDatabase(ADDON..": Layout [BlizzardObjectivesTracker]", BlizzardObjectivesTracker)
CogWheel("LibDB"):NewDatabase(ADDON..": Layout [Minimap]", Minimap)
CogWheel("LibDB"):NewDatabase(ADDON..": Layout [TooltipStyling]", TooltipStyling)
CogWheel("LibDB"):NewDatabase(ADDON..": Layout [UnitFramePlayer]", UnitFramePlayer)
CogWheel("LibDB"):NewDatabase(ADDON..": Layout [UnitFramePlayerHUD]", UnitFramePlayerHUD)
CogWheel("LibDB"):NewDatabase(ADDON..": Layout [UnitFrameTarget]", UnitFrameTarget)
CogWheel("LibDB"):NewDatabase(ADDON..": Layout [UnitFrameToT]", UnitFrameToT)
CogWheel("LibDB"):NewDatabase(ADDON..": Layout [UnitFramePet]", UnitFramePet)

